@@ -8,19 +8,19 @@ AccessTypeDict = {
             "rdfs:subClassOf": {"@id": "schema:Enumeration"},
         },
         {
-            "@id": "dandi:Open",
+            "@id": "dandi:OpenAccess",
             "@type": "dandi:AccessType",
             "rdfs:comment": "The dandiset is openly accessible",
             "rdfs:label": "Open access",
         },
         {
-            "@id": "dandi:Embargoed",
+            "@id": "dandi:EmbargoedAccess",
             "@type": "dandi:AccessType",
             "rdfs:comment": "The dandiset is embargoed",
             "rdfs:label": "Embargoed",
         },
         {
-            "@id": "dandi:Restricted",
+            "@id": "dandi:RestrictedAccess",
             "@type": "dandi:AccessType",
             "rdfs:comment": "The dandiset is restricted",
             "rdfs:label": "Restricted",
@@ -167,203 +167,209 @@ RelationTypeDict = {
             ),
         },
         {
-            "@id": "dandi:IsCitedBy",
+            "@id": "dcite:IsCitedBy",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates that B includes A in a citation",
             "rdfs:label": "IsCitedBy",
         },
         {
-            "@id": "dandi:Cites",
+            "@id": "dcite:Cites",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates that A includes B in a citation",
             "rdfs:label": "Cites",
         },
         {
-            "@id": "dandi:IsSupplementTo",
+            "@id": "dcite:IsSupplementTo",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates that A is a supplement to B",
             "rdfs:label": "IsSupplementTo",
         },
         {
-            "@id": "dandi:IsSupplementedBy",
+            "@id": "dcite:IsSupplementedBy",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates that B is a supplement to A",
             "rdfs:label": "IsSupplementedBy",
         },
         {
-            "@id": "dandi:IsContinuedBy",
+            "@id": "dcite:IsContinuedBy",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates A is continued by the work B",
             "rdfs:label": "IsContinuedBy",
         },
         {
-            "@id": "dandi:Continues",
+            "@id": "dcite:Continues",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates A is a continuation of the work B",
             "rdfs:label": "Continues",
         },
         {
-            "@id": "dandi:Describes",
+            "@id": "dcite:Describes",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates A describes B",
             "rdfs:label": "Describes",
         },
         {
-            "@id": "dandi:IsDescribedBy",
+            "@id": "dcite:IsDescribedBy",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates A is described by B",
             "rdfs:label": "IsDescribedBy",
         },
         {
-            "@id": "dandi:HasMetadata",
+            "@id": "dcite:HasMetadata",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates resource A has additional metadata B",
             "rdfs:label": "HasMetadata",
         },
         {
-            "@id": "dandi:IsMetadataFor",
+            "@id": "dcite:IsMetadataFor",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates additional metadata A for a resource B",
             "rdfs:label": "IsMetadataFor",
         },
         {
-            "@id": "dandi:HasVersion",
+            "@id": "dcite:HasVersion",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates A has a version (B)",
             "rdfs:label": "HasVersion",
         },
         {
-            "@id": "dandi:IsVersionOf",
+            "@id": "dcite:IsVersionOf",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates A is a version of B",
             "rdfs:label": "IsVersionOf",
         },
         {
-            "@id": "dandi:IsNewVersionOf",
+            "@id": "dcite:IsNewVersionOf",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates A is a new edition of B",
             "rdfs:label": "IsNewVersionOf",
         },
         {
-            "@id": "dandi:IsPreviousVersionOf",
+            "@id": "dcite:IsPreviousVersionOf",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates A is a previous edition of B",
             "rdfs:label": "IsPreviousVersionOf",
         },
         {
-            "@id": "dandi:IsPartOf",
+            "@id": "dcite:IsPartOf",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates A is a portion of B",
             "rdfs:label": "IsPartOf",
         },
         {
-            "@id": "dandi:HasPart",
+            "@id": "dcite:HasPart",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates A includes the part B",
             "rdfs:label": "HasPart",
         },
         {
-            "@id": "dandi:IsReferencedBy",
+            "@id": "dcite:IsReferencedBy",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates A is used as a source of information by B",
             "rdfs:label": "IsReferencedBy",
         },
         {
-            "@id": "dandi:References",
-            "@type": "dandi:RelationType",
+            "@id": "dcite:References",
+            "@type": "dcite:RelationType",
             "rdfs:comment": "Indicates B is used as a source of information for A",
             "rdfs:label": "References",
         },
         {
-            "@id": "dandi:IsDocumentedBy",
+            "@id": "dcite:IsDocumentedBy",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates B is documentation about/explaining A",
             "rdfs:label": "IsDocumentedBy",
         },
         {
-            "@id": "dandi:Documents",
+            "@id": "dcite:Documents",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates A is documentation about B",
             "rdfs:label": "Documents",
         },
         {
-            "@id": "dandi:IsCompiledBy",
+            "@id": "dcite:IsCompiledBy",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates B is used to compile or create A",
             "rdfs:label": "IsCompiledBy",
         },
         {
-            "@id": "dandi:Compiles",
+            "@id": "dcite:Compiles",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates B is the result of a compile or creation event using A",
             "rdfs:label": "Compiles",
         },
         {
-            "@id": "dandi:IsVariantFormOf",
+            "@id": "dcite:IsVariantFormOf",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates A is a variant or different form of B",
             "rdfs:label": "IsVariantFormOf",
         },
         {
-            "@id": "dandi:IsOriginalFormOf",
+            "@id": "dcite:IsOriginalFormOf",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates A is the original form of B",
             "rdfs:label": "IsOriginalFormOf",
         },
         {
-            "@id": "dandi:IsIdenticalTo",
+            "@id": "dcite:IsIdenticalTo",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates that A is identical to B",
             "rdfs:label": "IsIdenticalTo",
         },
         {
-            "@id": "dandi:IsReviewedBy",
+            "@id": "dcite:IsReviewedBy",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates that A is reviewed by B",
             "rdfs:label": "IsReviewedBy",
         },
         {
-            "@id": "dandi:Reviews",
+            "@id": "dcite:Reviews",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates that A is a review of B",
             "rdfs:label": "Reviews",
         },
         {
-            "@id": "dandi:IsDerivedFrom",
+            "@id": "dcite:IsDerivedFrom",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates B is a source upon which A is based",
             "rdfs:label": "IsDerivedFrom",
         },
         {
-            "@id": "dandi:IsSourceOf",
+            "@id": "dcite:IsSourceOf",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates A is a source upon which B is based",
             "rdfs:label": "IsSourceOf",
         },
         {
-            "@id": "dandi:IsRequiredBy",
+            "@id": "dcite:IsRequiredBy",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates A is required by B",
             "rdfs:label": "IsRequiredBy",
         },
         {
-            "@id": "dandi:Requires",
+            "@id": "dcite:Requires",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates A requires B",
             "rdfs:label": "Requires",
         },
         {
-            "@id": "dandi:Obsoletes",
+            "@id": "dcite:Obsoletes",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates A replaces B",
             "rdfs:label": "Obsoletes",
         },
         {
-            "@id": "dandi:IsObsoletedBy",
+            "@id": "dcite:IsObsoletedBy",
             "@type": "dandi:RelationType",
             "rdfs:comment": "Indicates A is replaced by B",
             "rdfs:label": "IsObsoletedBy",
         },
+        {
+            "@id": "dcite:IsPublishedIn",
+            "@type": "dandi:RelationType",
+            "rdfs:comment": "Indicates A is published in B",
+            "rdfs:label": "IsPublishedIn",
+        },
     ]
 }
 
@@ -380,32 +386,32 @@ ParticipantRelationTypeDict = {
             ),
         },
         {
-            "@id": "dandi:IsChildOf",
-            "@type": "dandi:RelationType",
+            "@id": "dandi:isChildOf",
+            "@type": "dandi:ParticipantRelationType",
             "rdfs:comment": "Indicates that A is a child of B",
             "rdfs:label": "Child of",
         },
         {
             "@id": "dandi:isParentOf",
-            "@type": "dandi:RelationType",
+            "@type": "dandi:ParticipantRelationType",
             "rdfs:comment": "Indicates that A is a parent of B",
             "rdfs:label": "Parent of",
         },
         {
-            "@id": "dandi:IsSiblingOf",
-            "@type": "dandi:RelationType",
+            "@id": "dandi:isSiblingOf",
+            "@type": "dandi:ParticipantRelationType",
             "rdfs:comment": "Indicates that A is a sibling of B",
             "rdfs:label": "Sibling of",
         },
         {
-            "@id": "dandi:IsMonozygoticTwinOf",
-            "@type": "dandi:RelationType",
+            "@id": "dandi:isMonozygoticTwinOf",
+            "@type": "dandi:ParticipantRelationType",
             "rdfs:comment": "Indicates that A is a monozygotic twin of B",
             "rdfs:label": "Monozygotic twin of",
         },
         {
-            "@id": "dandi:IsDizygoticTwinOf",
-            "@type": "dandi:RelationType",
+            "@id": "dandi:isDizygoticTwinOf",
+            "@type": "dandi:ParticipantRelationType",
             "rdfs:comment": "Indicates that A is a dizygotic twin of B",
             "rdfs:label": "Dizygotic twin of",
         },
@@ -422,169 +428,169 @@ RoleTypeDict = {
             "rdfs:subClassOf": {"@id": "schema:Enumeration"},
         },
         {
-            "@id": "dandi:Author",
+            "@id": "dcite:Author",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Author",
             "rdfs:label": "Author",
         },
         {
-            "@id": "dandi:Conceptualization",
+            "@id": "dcite:Conceptualization",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Conceptualization",
             "rdfs:label": "Conceptualization",
         },
         {
-            "@id": "dandi:ContactPerson",
+            "@id": "dcite:ContactPerson",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Contact Person",
             "rdfs:label": "Contact Person",
         },
         {
-            "@id": "dandi:DataCollector",
+            "@id": "dcite:DataCollector",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Data Collector",
             "rdfs:label": "Data Collector",
         },
         {
-            "@id": "dandi:DataCurator",
+            "@id": "dcite:DataCurator",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Data Curator",
             "rdfs:label": "Data Curator",
         },
         {
-            "@id": "dandi:DataManager",
+            "@id": "dcite:DataManager",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Data Manager",
             "rdfs:label": "Data Manager",
         },
         {
-            "@id": "dandi:FormalAnalysis",
+            "@id": "dcite:FormalAnalysis",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Formal Analysis",
             "rdfs:label": "Formal Analysis",
         },
         {
-            "@id": "dandi:FundingAcquisition",
+            "@id": "dcite:FundingAcquisition",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Funding Acquisition",
             "rdfs:label": "Funding Acquisition",
         },
         {
-            "@id": "dandi:Investigation",
+            "@id": "dcite:Investigation",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Investigation",
             "rdfs:label": "Investigation",
         },
         {
-            "@id": "dandi:Maintainer",
+            "@id": "dcite:Maintainer",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Maintainer",
             "rdfs:label": "Maintainer",
         },
         {
-            "@id": "dandi:Methodology",
+            "@id": "dcite:Methodology",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Methodology",
             "rdfs:label": "Methodology",
         },
         {
-            "@id": "dandi:Producer",
+            "@id": "dcite:Producer",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Producer",
             "rdfs:label": "Producer",
         },
         {
-            "@id": "dandi:ProjectLeader",
+            "@id": "dcite:ProjectLeader",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Project Leader",
             "rdfs:label": "Project Leader",
         },
         {
-            "@id": "dandi:ProjectManager",
+            "@id": "dcite:ProjectManager",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Project Manager",
             "rdfs:label": "Project Manager",
         },
         {
-            "@id": "dandi:ProjectMember",
+            "@id": "dcite:ProjectMember",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Project Member",
             "rdfs:label": "Project Member",
         },
         {
-            "@id": "dandi:ProjectAdministration",
+            "@id": "dcite:ProjectAdministration",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Project Administration",
             "rdfs:label": "Project Administration",
         },
         {
-            "@id": "dandi:Researcher",
+            "@id": "dcite:Researcher",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Researcher",
             "rdfs:label": "Researcher",
         },
         {
-            "@id": "dandi:Resources",
+            "@id": "dcite:Resources",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Resources",
             "rdfs:label": "Resources",
         },
         {
-            "@id": "dandi:Software",
+            "@id": "dcite:Software",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Software",
             "rdfs:label": "Software",
         },
         {
-            "@id": "dandi:Supervision",
+            "@id": "dcite:Supervision",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Supervision",
             "rdfs:label": "Supervision",
         },
         {
-            "@id": "dandi:Validation",
+            "@id": "dcite:Validation",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Validation",
             "rdfs:label": "Validation",
         },
         {
-            "@id": "dandi:Visualization",
+            "@id": "dcite:Visualization",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Visualization",
             "rdfs:label": "Visualization",
         },
         {
-            "@id": "dandi:Funder",
+            "@id": "dcite:Funder",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Funder",
             "rdfs:label": "Funder",
         },
         {
-            "@id": "dandi:Sponsor",
+            "@id": "dcite:Sponsor",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Sponsor",
             "rdfs:label": "Sponsor",
         },
         {
-            "@id": "dandi:StudyParticipant",
+            "@id": "dcite:StudyParticipant",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Participant in a study",
             "rdfs:label": "Study participant",
         },
         {
-            "@id": "dandi:Affiliation",
+            "@id": "dcite:Affiliation",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Affiliated with an entity",
             "rdfs:label": "Affiliation",
         },
         {
-            "@id": "dandi:EthicsApproval",
+            "@id": "dcite:EthicsApproval",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Approved ethics protocol",
             "rdfs:label": "Ethics approval",
         },
         {
-            "@id": "dandi:Other",
+            "@id": "dcite:Other",
             "@type": "dandi:RoleType",
             "rdfs:comment": "Other",
             "rdfs:label": "Other",
