@@ -6,7 +6,7 @@ import sys
 from typing import Any, Dict, List, Optional, Type, Union
 
 from pydantic import UUID4, BaseModel, ByteSize, EmailStr, Field, HttpUrl, validator
-from ruamel import yaml
+from pydantic.main import ModelMetaclass
 
 from .consts import DANDI_SCHEMA_VERSION
 from .model_types import (
@@ -25,7 +25,8 @@ if sys.version_info < (3, 8):
 else:
     from typing import Literal
 
-TempOptional = Optional
+
+NAME_PATTERN = r"^([\w\s\-]+)?,\s+([\w\s\-\.]+)?$"
 
 
 def create_enum(data):
@@ -63,40 +64,6 @@ def split_name(name):
     return " ".join(labels)
 
 
-def model2graph(model):
-    """Convert a model to a JSON-LD graph"""
-    klass = {}
-    klass["rdfs:comment"] = model.__doc__
-    klass["rdfs:label"] = split_name(model.__name__)
-    klass["rdf:type"] = "rdfs:Class"
-    for key, val in model._ldmeta.items():
-        if key == "nskey":
-            klass["@id"] = f"{val}:{model.__name__}"
-        else:
-            klass[key] = val
-    graph = [dict(sorted(klass.items()))]
-    for key, val in sorted(model.__fields__.items()):
-        prefix = val.field_info.extra["nskey"]
-        prop = {"@id": f"{prefix}:{key}"}
-        prop["schema:domainIncludes"] = klass["@id"]
-        if prefix != "schema":
-            prop["@type"] = "rdf:Property"
-            if val.field_info.title:
-                prop["rdfs:label"] = val.field_info.title
-            else:
-                prop["rdfs:label"] = split_name(key)
-            if val.field_info.description:
-                prop["rdfs:comment"] = val.field_info.description
-            if "rangeIncludes" in val.field_info.extra:
-                prop["schema:rangeIncludes"] = val.field_info.extra["rangeIncludes"]
-        graph.append(dict(sorted(prop.items())))
-    jsonld_doc = {"@context": "../context/base.json", "@graph": graph}
-    with open(f"terms/{model.__name__}.yaml", "w") as fp:
-        fp.write("# AUTOGENERATED - DO NOT EDIT\n")
-        yaml.safe_dump(jsonld_doc, fp, indent=2)
-    return jsonld_doc
-
-
 if len(AccessTypeDict["@graph"]) > 2:
     AccessTypeDict["@graph"].pop()
     AccessTypeDict["@graph"].pop()
@@ -116,188 +83,6 @@ def diff_models(model1, model2):
             print(f"{field} is different")
 
 
-DATACITE_CONTRTYPE = {
-    "ContactPerson",
-    "DataCollector",
-    "DataCurator",
-    "DataManager",
-    "Distributor",
-    "Editor",
-    "HostingInstitution",
-    "Producer",
-    "ProjectLeader",
-    "ProjectManager",
-    "ProjectMember",
-    "RegistrationAgency",
-    "RegistrationAuthority",
-    "RelatedPerson",
-    "Researcher",
-    "ResearchGroup",
-    "RightsHolder",
-    "Sponsor",
-    "Supervisor",
-    "WorkPackageLeader",
-    "Other",
-}
-
-
-DATACITE_IDENTYPE = {
-    "ARK",
-    "arXiv",
-    "bibcode",
-    "DOI",
-    "EAN13",
-    "EISSN",
-    "Handle",
-    "IGSN",
-    "ISBN",
-    "ISSN",
-    "ISTC",
-    "LISSN",
-    "LSID",
-    "PMID",
-    "PURL",
-    "UPC",
-    "URL",
-    "URN",
-    "w3id",
-}
-DATACITE_MAP = dict([(el.lower(), el) for el in DATACITE_IDENTYPE])
-
-
-def to_datacite(meta):
-    dandiset_id = meta.identifier.split(":")[1]
-    doi = meta.doi
-
-    attributes = {}
-    attributes["identifiers"] = [
-        # TODO: the first elementis ignored, not sure how to fix it...
-        {"identifier": f"https://doi.org/{doi}", "identifierType": "DOI"},
-        {
-            "identifier": f"https://identifiers.org/DANDI:{dandiset_id}/{meta.version}",
-            "identifierType": "URL",
-        },
-    ]
-
-    attributes["doi"] = doi
-    attributes["titles"] = [{"title": meta.name}]
-    attributes["descriptions"] = [
-        {"description": meta.description, "descriptionType": "Abstract"}
-    ]
-    attributes["publisher"] = "DANDI Archive"
-    attributes["publicationYear"] = str(meta.datePublished.year)
-    # not sure about it dandi-api had "resourceTypeGeneral": "NWB"
-    attributes["types"] = {"resourceType": "NWB", "resourceTypeGeneral": "Dataset"}
-    # meta has also attribute url, but it often empty
-    attributes["url"] = meta.url
-    # assuming that all licenses are from SPDX?
-    attributes["rightsList"] = [
-        {
-            "schemeURI": "https://spdx.org/licenses/",
-            "rightsIdentifierScheme": "SPDX",
-            "rightsIdentifier": el.name,
-        }
-        for el in meta.license
-    ]
-    attributes["schemaVersion"] = "http://datacite.org/schema/kernel-4"
-
-    contributors = []
-    creators = []
-    for contr_el in meta.contributor:
-        if RoleType("dandi:Sponsor") in contr_el.roleName:
-            # no info about "funderIdentifierType", "awardUri", "awardTitle"
-            dict_fund = {"funderName": contr_el.name}
-            if contr_el.identifier:
-                dict_fund["funderIdentifier"] = contr_el.identifier
-            if contr_el.awardNumber:
-                dict_fund["awardNumber"] = contr_el.awardNumber
-            attributes.setdefault("fundingReferences", []).append(dict_fund)
-            # if no more roles, it shouldn't be added to creators or contributors
-            contr_el.roleName.remove(RoleType("dandi:Sponsor"))
-            if not contr_el.roleName:
-                continue
-
-        contr_dict = {
-            "name": contr_el.name,
-            "contributorName": contr_el.name,
-            "schemeURI": "orcid.org",
-        }
-        if isinstance(contr_el, Person):
-            contr_dict["nameType"] = "Personal"
-            if len(contr_el.name.split(",")) == 2:
-                contr_dict["familyName"], contr_dict["givenName"] = contr_el.name.split(
-                    ","
-                )
-            if getattr(contr_el, "affiliation"):
-                contr_dict["affiliation"] = [
-                    {"name": el.name} for el in contr_el.affiliation
-                ]
-            else:
-                contr_dict["affiliation"] = []
-        elif isinstance(contr_el, Organization):
-            contr_dict["nameType"] = "Organizational"
-
-        if RoleType("dandi:Author") in getattr(contr_el, "roleName"):
-            create_dict = deepcopy(contr_dict)
-            create_dict["creatorName"] = create_dict.pop("contributorName")
-            creators.append(create_dict)
-            contr_el.roleName.remove(RoleType("dandi:Author"))
-            # if no more roles, it shouldn't be added to contributors
-            if not contr_el.roleName:
-                continue
-
-        if getattr(contr_el, "roleName"):
-            contr_all = [
-                el.name for el in contr_el.roleName if el.name in DATACITE_CONTRTYPE
-            ]
-            if contr_all:
-                contr_dict["contributorType"] = contr_all[0]
-            else:
-                contr_dict["contributorType"] = "Other"
-        contributors.append(contr_dict)
-
-    # if there are no creators, the first contributor is also treated as the creator
-    if not creators and contributors:
-        creators = [deepcopy(contributors[0])]
-        creators[0]["creatorName"] = creators[0].pop("contributorName")
-        creators[0].pop("contributorType")
-
-    attributes["contributors"] = contributors
-    attributes["creators"] = creators
-
-    if getattr(meta, "relatedResource"):
-        attributes["relatedIdentifiers"] = []
-        for rel_el in meta.relatedResource:
-            ident = rel_el.identifier.split(":")
-            if len(ident) == 2:
-                ident_tp, ident_nr = ident
-                if ident_tp.lower() in DATACITE_MAP:
-                    ident_tp = DATACITE_MAP[ident_tp.lower()]
-                else:
-                    raise ValueError(
-                        f"identifier has to be from the list: {DATACITE_IDENTYPE}, "
-                        f"but {ident_tp} provided"
-                    )
-            else:
-                raise ValueError(
-                    "identifier is expected to be type:number,"
-                    f" got {rel_el.identifier}"
-                )
-            rel_dict = {
-                "relatedIdentifier": ident_nr,
-                # in theory it should be from the specific list that contains e.g. DOI, arXiv, ...
-                "relatedIdentifierType": ident_tp,
-                "relationType": rel_el.relation.name,
-            }
-            attributes["relatedIdentifiers"].append(rel_dict)
-
-    if getattr(meta, "keywords"):
-        attributes["subjects"] = [{"subject": el} for el in meta.keywords]
-
-    datacite_dict = {"data": {"id": doi, "type": "dois", "attributes": attributes}}
-    return datacite_dict
-
-
 def _sanitize(o):
     if isinstance(o, dict):
         return {_sanitize(k): _sanitize(v) for k, v in o.items()}
@@ -313,7 +98,15 @@ class HandleKeyEnumEncoder(json.JSONEncoder):
         return super().encode(_sanitize(o))
 
 
-class DandiBaseModel(BaseModel):
+class DandiBaseModelMetaclass(ModelMetaclass):
+    def __new__(cls, name, bases, dct):
+        sk_name = dct.pop("schemaKey", None) or name
+        dct["schemaKey"]: Literal[sk_name] = Field(sk_name, readOnly=True)
+        objcls = super().__new__(cls, name, bases, dct)
+        return objcls
+
+
+class DandiBaseModel(BaseModel, metaclass=DandiBaseModelMetaclass):
     id: Optional[str] = Field(description="Uniform resource identifier", readOnly=True)
 
     @classmethod
@@ -351,6 +144,12 @@ class DandiBaseModel(BaseModel):
         def schema_extra(schema: Dict[str, Any], model) -> None:
             schema["title"] = name2title(schema["title"])
             for prop, value in schema.get("properties", {}).items():
+                if schema["title"] == "Person":
+                    if prop == "name":
+                        # JSON schema doesn't support validating unicode
+                        # characters using the \w pattern, but Python does. So
+                        # we are dropping the regex pattern for the schema.
+                        del value["pattern"]
                 if value.get("title") is None or value["title"] == prop.title():
                     value["title"] = name2title(prop)
                 if value.get("format", None) == "uri":
@@ -380,10 +179,13 @@ class DandiBaseModel(BaseModel):
                 # In pydantic 1.8+ all Literals are mapped on to enum
                 # This presently breaks the schema editor UI. Revert
                 # to const when generating the schema.
+                # Note: this no longer happens with custom metaclass
                 if prop == "schemaKey":
-                    if len(value["enum"]) == 1:
+                    if "enum" in value and len(value["enum"]) == 1:
                         value["const"] = value["enum"][0]
                         del value["enum"]
+                    else:
+                        value["const"] = value["default"]
 
 
 class PropertyValue(DandiBaseModel):
@@ -413,7 +215,7 @@ DANDI = str
 RRID = str
 
 
-class TypeModel(DandiBaseModel):
+class BaseType(DandiBaseModel):
     """Base class for enumerated types"""
 
     identifier: Optional[Union[HttpUrl, str]] = Field(
@@ -425,47 +227,34 @@ class TypeModel(DandiBaseModel):
     name: Optional[str] = Field(
         description="The name of the item.", max_length=150, nskey="schema"
     )
-    schemaKey: Literal["GenericType"] = Field("GenericType", readOnly=True)
     _ldmeta = {"rdfs:subClassOf": ["prov:Entity", "schema:Thing"], "nskey": "dandi"}
 
 
-class AssayType(TypeModel):
+class AssayType(BaseType):
     """OBI based identifier for the assay(s) used"""
 
-    schemaKey: Literal["AssayType"] = Field("AssayType", readOnly=True)
 
-
-class SampleType(TypeModel):
+class SampleType(BaseType):
     """OBI based identifier for the sample type used"""
 
-    schemaKey: Literal["SampleType"] = Field("SampleType", readOnly=True)
 
-
-class Anatomy(TypeModel):
+class Anatomy(BaseType):
     """UBERON or other identifier for anatomical part studied"""
 
-    schemaKey: Literal["Anatomy"] = Field("Anatomy", readOnly=True)
 
-
-class StrainType(TypeModel):
+class StrainType(BaseType):
     """Identifier for the strain of the sample"""
 
-    schemaKey: Literal["StrainType"] = Field("StrainType", readOnly=True)
 
-
-class SexType(TypeModel):
+class SexType(BaseType):
     """Identifier for the sex of the sample"""
 
-    schemaKey: Literal["SexType"] = Field("SexType", readOnly=True)
 
-
-class SpeciesType(TypeModel):
+class SpeciesType(BaseType):
     """Identifier for species of the sample"""
 
-    schemaKey: Literal["SpeciesType"] = Field("SpeciesType", readOnly=True)
 
-
-class Disorder(TypeModel):
+class Disorder(BaseType):
     """Biolink, SNOMED, or other identifier for disorder studied"""
 
     dxdate: Optional[List[Union[date, datetime]]] = Field(
@@ -475,34 +264,28 @@ class Disorder(TypeModel):
         nskey="dandi",
         rangeIncludes="schema:Date",
     )
-    schemaKey: Literal["Disorder"] = Field("Disorder", readOnly=True)
 
 
-class ApproachType(TypeModel):
+class GenericType(BaseType):
+    """An object to capture any type for about"""
+
+
+class ApproachType(BaseType):
     """Identifier for approach used"""
 
-    schemaKey: Literal["ApproachType"] = Field("ApproachType", readOnly=True)
 
-
-class MeasurementTechniqueType(TypeModel):
+class MeasurementTechniqueType(BaseType):
     """Identifier for measurement technique used"""
 
-    schemaKey: Literal["MeasurementTechniqueType"] = Field(
-        "MeasurementTechniqueType", readOnly=True
-    )
 
-
-class StandardsType(TypeModel):
+class StandardsType(BaseType):
     """Identifier for data standard used"""
 
-    schemaKey: Literal["StandardsType"] = Field("StandardsType", readOnly=True)
-
 
 class ContactPoint(DandiBaseModel):
     email: Optional[EmailStr] = Field(None, nskey="schema")
     url: Optional[HttpUrl] = Field(None, nskey="schema")
 
-    schemaKey: Literal["ContactPoint"] = Field("ContactPoint", readOnly=True)
     _ldmeta = {"nskey": "schema"}
 
 
@@ -556,7 +339,22 @@ class Organization(Contributor):
         description="Contact for the organization",
         nskey="schema",
     )
-    schemaKey: Literal["Organization"] = Field("Organization", readOnly=True)
+    _ldmeta = {
+        "rdfs:subClassOf": ["schema:Organization", "prov:Organization"],
+        "nskey": "dandi",
+    }
+
+
+class Affiliation(DandiBaseModel):
+    identifier: Optional[RORID] = Field(
+        None,
+        title="A ror.org identifier",
+        description="Use an ror.org identifier for institutions",
+        regex=r"^https://ror.org/[a-z0-9]+$",
+        nskey="schema",
+    )
+    name: str = Field(None, nskey="schema")
+
     _ldmeta = {
         "rdfs:subClassOf": ["schema:Organization", "prov:Organization"],
         "nskey": "dandi",
@@ -573,15 +371,15 @@ class Person(Contributor):
     )
     name: str = Field(
         description="Use the format: familyname, given names ...",
+        regex=NAME_PATTERN,
         nskey="schema",
         examples=["Lovelace, Augusta Ada", "Smith, John", "Chan, Kong-sang"],
     )
-    affiliation: List[Organization] = Field(
+    affiliation: List[Affiliation] = Field(
         None,
         description="An organization that this person is affiliated with.",
         nskey="schema",
     )
-    schemaKey: Literal["Person"] = Field("Person", readOnly=True)
 
     _ldmeta = {"rdfs:subClassOf": ["schema:Person", "prov:Person"], "nskey": "dandi"}
 
@@ -599,7 +397,6 @@ class Software(DandiBaseModel):
     url: Optional[HttpUrl] = Field(
         None, description="Web page for the software", nskey="schema"
     )
-    schemaKey: Literal["Software"] = Field("Software", readOnly=True)
 
     _ldmeta = {
         "rdfs:subClassOf": ["schema:SoftwareApplication", "prov:Software"],
@@ -616,7 +413,6 @@ class Agent(DandiBaseModel):
     )
     name: str = Field(nskey="schema")
     url: Optional[HttpUrl] = Field(None, nskey="schema")
-    schemaKey: Literal["Software"] = Field("Agent", readOnly=True)
 
     _ldmeta = {
         "rdfs:subClassOf": ["prov:Agent"],
@@ -698,24 +494,45 @@ class AssetsSummary(DandiBaseModel):
     """Summary over assets contained in a dandiset (published or not)"""
 
     # stats which are not stats
-    numberOfBytes: int = Field(readOnly=True, sameas="schema:contentSize")
-    numberOfFiles: int = Field(readOnly=True)  # universe
+    numberOfBytes: int = Field(readOnly=True, gt=0, sameas="schema:contentSize")
+    numberOfFiles: int = Field(readOnly=True, gt=0)  # universe
     numberOfSubjects: Optional[int] = Field(None, readOnly=True)  # NWB + BIDS
     numberOfSamples: Optional[int] = Field(None, readOnly=True)  # more of NWB
     numberOfCells: Optional[int] = Field(None, readOnly=True)
 
-    dataStandard: List[StandardsType] = Field(
+    dataStandard: Optional[List[StandardsType]] = Field(
         readOnly=True
     )  # TODO: types of things NWB, BIDS
     # Web UI: icons per each modality?
-    approach: List[ApproachType] = Field(
+    approach: Optional[List[ApproachType]] = Field(
         readOnly=True
     )  # TODO: types of things, BIDS etc...
     # Web UI: could be an icon with number, which if hovered on  show a list?
-    measurementTechnique: List[MeasurementTechniqueType] = Field(readOnly=True)
-    variableMeasured: Optional[List[str]] = Field(None, readOnly=True)
+    measurementTechnique: Optional[List[MeasurementTechniqueType]] = Field(
+        readOnly=True, nskey="schema"
+    )
+    variableMeasured: Optional[List[str]] = Field(None, readOnly=True, nskey="schema")
 
-    species: List[SpeciesType] = Field(readOnly=True)
+    species: Optional[List[SpeciesType]] = Field(readOnly=True)
+
+    _ldmeta = {
+        "rdfs:subClassOf": ["schema:CreativeWork", "prov:Entity"],
+        "nskey": "dandi",
+    }
+
+
+class Equipment(DandiBaseModel):
+
+    identifier: Optional[Identifier] = Field(None, nskey="schema")
+    name: str = Field(
+        title="Title",
+        description="A name for the equipment.",
+        max_length=150,
+        nskey="schema",
+    )
+    description: Optional[str] = Field(
+        None, description="The description of the activity.", nskey="schema"
+    )
 
     _ldmeta = {
         "rdfs:subClassOf": ["schema:CreativeWork", "prov:Entity"],
@@ -744,8 +561,7 @@ class Activity(DandiBaseModel):
     wasAssociatedWith: Optional[
         List[Union[Person, Organization, Software, Agent]]
     ] = Field(None, nskey="prov")
-
-    schemaKey: Literal["Activity"] = Field("Activity", readOnly=True)
+    used: Optional[List[Equipment]] = Field(None, nskey="prov")
 
     _ldmeta = {"rdfs:subClassOf": ["prov:Activity", "schema:Thing"], "nskey": "dandi"}
 
@@ -760,7 +576,6 @@ class Project(Activity):
     description: Optional[str] = Field(
         None, description="A brief description of the project.", nskey="schema"
     )
-    schemaKey: Literal["Project"] = Field("Project", readOnly=True)
 
 
 class Session(Activity):
@@ -773,40 +588,33 @@ class Session(Activity):
     description: Optional[str] = Field(
         None, description="A brief description of the session.", nskey="schema"
     )
-    schemaKey: Literal["Session"] = Field("Session", readOnly=True)
 
 
 class PublishActivity(Activity):
-    schemaKey: Literal["PublishActivity"] = Field("PublishActivity", readOnly=True)
+    pass
 
 
 class Locus(DandiBaseModel):
     identifier: Union[Identifier, List[Identifier]] = Field(
-        description="Identifier for genotyping locus"
+        description="Identifier for genotyping locus", nskey="schema"
     )
-    locus_type: str = Field()
-    symbol: str = Field()
-    schemaKey: Literal["Locus"] = Field("Locus", readOnly=True)
+    locusType: Optional[str] = Field(None)
     _ldmeta = {"nskey": "dandi"}
 
 
 class Allele(DandiBaseModel):
     identifier: Union[Identifier, List[Identifier]] = Field(
-        description="Identifier for genotyping allele"
+        description="Identifier for genotyping allele", nskey="schema"
     )
-    allele_type: str = Field()
-    symbol: str = Field()
-    schemaKey: Literal["Allele"] = Field("Allele", readOnly=True)
+    alleleSymbol: Optional[str] = Field(None)
+    alleleType: Optional[str] = Field(None)
     _ldmeta = {"nskey": "dandi"}
 
 
 class GenotypeInfo(DandiBaseModel):
     locus: Locus = Field(description="Locus at which information was extracted")
-    alleles: List[Allele] = Field(
-        max_items=3, description="Information about one allele"
-    )
+    alleles: List[Allele] = Field(description="Information about alleles at the locus")
     wasGeneratedBy: Optional[List["Session"]] = Field(None, nskey="prov")
-    schemaKey: Literal["GenotypeInfo"] = Field("GenotypeInfo", readOnly=True)
     _ldmeta = {"nskey": "dandi"}
 
 
@@ -875,8 +683,6 @@ class Participant(DandiBaseModel):
     relatedParticipant: Optional[List[RelatedParticipant]] = Field(None, nskey="dandi")
     sameAs: Optional[List[Identifier]] = Field(None, nskey="schema")
 
-    schemaKey: Literal["Participant"] = Field("Participant", readOnly=True)
-
     _ldmeta = {
         "rdfs:subClassOf": ["prov:Agent"],
         "rdfs:label": "Information about the participant.",
@@ -908,8 +714,6 @@ class BioSample(DandiBaseModel):
     sameAs: Optional[List[Identifier]] = Field(None, nskey="schema")
     hasMember: Optional[List[Identifier]] = Field(None, nskey="prov")
 
-    schemaKey: Literal["BioSample"] = Field("BioSample", readOnly=True)
-
     _ldmeta = {
         "rdfs:subClassOf": ["schema:Thing", "prov:Entity"],
         "rdfs:label": "Information about the biosample.",
@@ -920,10 +724,6 @@ class BioSample(DandiBaseModel):
 BioSample.update_forward_refs()
 
 
-class Identifiable(DandiBaseModel):
-    identifier: Optional[Identifier] = Field(readOnly=True, nskey="schema")
-
-
 class CommonModel(DandiBaseModel):
     schemaVersion: str = Field(
         default=DANDI_SCHEMA_VERSION, readOnly=True, nskey="schema"
@@ -944,7 +744,7 @@ class CommonModel(DandiBaseModel):
         description="Contributors to this item.",
         nskey="schema",
     )
-    about: Optional[List[Union[Disorder, Anatomy, TypeModel]]] = Field(
+    about: Optional[List[Union[Disorder, Anatomy, GenericType]]] = Field(
         None,
         title="Subject matter of the dataset",
         description="The subject matter of the content, such as disorders, brain anatomy.",
@@ -975,7 +775,7 @@ class CommonModel(DandiBaseModel):
     # Linking to this dandiset or the larger thing
     access: List[AccessRequirements] = Field(
         title="Access information",
-        default_factory=lambda: [AccessRequirements(status=AccessType.Open)],
+        default_factory=lambda: [AccessRequirements(status=AccessType.OpenAccess)],
         nskey="dandi",
     )
     url: Optional[HttpUrl] = Field(
@@ -1000,11 +800,11 @@ class CommonModel(DandiBaseModel):
         return json.loads(self.json(exclude_none=True, cls=HandleKeyEnumEncoder))
 
 
-class DandisetMeta(CommonModel, Identifiable):
+class Dandiset(CommonModel):
     """A body of structured information describing a DANDI dataset."""
 
     @validator("contributor")
-    def check_data(cls, values):
+    def contributor_musthave_contact(cls, values):
         contacts = []
         for val in values:
             if val.roleName and RoleType.ContactPerson in val.roleName:
@@ -1052,13 +852,13 @@ class DandisetMeta(CommonModel, Identifiable):
         min_items=1, description="Licenses associated with the item.", nskey="schema"
     )
 
-    citation: TempOptional[str] = Field(readOnly=True, nskey="schema")
+    citation: str = Field(readOnly=True, nskey="schema")
 
     # From assets
-    assetsSummary: TempOptional[AssetsSummary] = Field(readOnly=True, nskey="dandi")
+    assetsSummary: AssetsSummary = Field(readOnly=True, nskey="dandi")
 
     # From server (requested by users even for drafts)
-    manifestLocation: TempOptional[List[HttpUrl]] = Field(readOnly=True, nskey="dandi")
+    manifestLocation: List[HttpUrl] = Field(readOnly=True, min_items=1, nskey="dandi")
 
     version: str = Field(readOnly=True, nskey="schema")
 
@@ -1069,8 +869,6 @@ class DandisetMeta(CommonModel, Identifiable):
         nskey="prov",
     )
 
-    schemaKey: Literal["Dandiset"] = Field("Dandiset", readOnly=True)
-
     _ldmeta = {
         "rdfs:subClassOf": ["schema:Dataset", "prov:Entity"],
         "rdfs:label": "Information about the dataset",
@@ -1078,7 +876,7 @@ class DandisetMeta(CommonModel, Identifiable):
     }
 
 
-class BareAssetMeta(CommonModel):
+class BareAsset(CommonModel):
     """Metadata used to describe an asset anywhere (local or server).
 
     Derived from C2M2 (Level 0 and 1) and schema.org
@@ -1088,7 +886,11 @@ class BareAssetMeta(CommonModel):
     encodingFormat: Union[HttpUrl, str] = Field(
         title="File encoding format", nskey="schema"
     )
-    digest: Dict[DigestType, str] = Field(default_factory=dict)
+    digest: Dict[DigestType, str] = Field(
+        title="A map of dandi digests to their values", nskey="dandi"
+    )
+    path: str = Field(nskey="dandi")
+
     dateModified: Optional[datetime] = Field(
         nskey="schema", title="Asset (file or metadata) modification date and time"
     )
@@ -1096,8 +898,6 @@ class BareAssetMeta(CommonModel):
         nskey="dandi", title="Asset file modification date and time"
     )
 
-    path: str = Field(None, nskey="dandi")
-
     # this is from C2M2 level 1 - using EDAM vocabularies - in our case we would
     # need to come up with things for neurophys
     # TODO: waiting on input <https://github.com/dandi/dandi-cli/pull/226>
@@ -1125,7 +925,8 @@ class BareAssetMeta(CommonModel):
         nskey="prov",
     )
 
-    schemaKey: Literal["Asset"] = Field("Asset", readOnly=True)
+    # Bare asset is to be just Asset.
+    schemaKey = "Asset"
 
     _ldmeta = {
         "rdfs:subClassOf": ["schema:CreativeWork", "prov:Entity"],
@@ -1133,42 +934,65 @@ class BareAssetMeta(CommonModel):
         "nskey": "dandi",
     }
 
+    @validator("digest")
+    def digest_etag(cls, values):
+        try:
+            if len(values[DigestType.dandi_etag]) != 32:
+                raise ValueError
+        except KeyError:
+            raise ValueError("Digest is missing dandi-etag value.")
+        except ValueError:
+            raise ValueError(
+                f"Digest must have an appropriate dandi-etag value. "
+                f"Got {values[DigestType.dandi_etag]}"
+            )
+        return values
 
-class AssetMeta(BareAssetMeta, Identifiable):
+
+class Asset(BareAsset):
     """Metadata used to describe an asset on the server."""
 
-    id: Optional[str] = Field(readOnly=True, description="Uniform resource identifier")
-    identifier: Optional[UUID4] = Field(readOnly=True, nskey="schema")
-    # on publish or set by server
-    contentUrl: Optional[List[HttpUrl]] = Field(None, readOnly=True, nskey="schema")
+    # all of the following are set by server
+    id: str = Field(readOnly=True, description="Uniform resource identifier")
+    identifier: UUID4 = Field(readOnly=True, nskey="schema")
+    contentUrl: List[HttpUrl] = Field(None, readOnly=True, nskey="schema")
 
 
 class Publishable(DandiBaseModel):
-    id: str = Field(readOnly=True, description="Uniform resource identifier")
     publishedBy: Union[HttpUrl, PublishActivity] = Field(
         description="The URL should contain the provenance of the publishing process.",
         readOnly=True,
         nskey="dandi",
     )  # TODO: formalize "publish" activity to at least the Actor
     datePublished: datetime = Field(readOnly=True, nskey="schema")
-    url: HttpUrl = Field(
-        readOnly=True, description="permalink to the item", nskey="schema"
-    )
 
 
-class PublishedDandisetMeta(DandisetMeta, Publishable):
-    version: str = Field(readOnly=True, nskey="schema")
+class PublishedDandiset(Dandiset, Publishable):
     doi: str = Field(
         title="DOI",
         readOnly=True,
         regex=r"^10\.[A-Za-z0-9.\/-]+",
         nskey="dandi",
     )
-    assetsSummary: AssetsSummary = Field(readOnly=True, nskey="dandi")
+    url: HttpUrl = Field(
+        readOnly=True, description="permalink to the item", nskey="schema"
+    )
+
+    schemaKey = "Dandiset"
 
 
-class PublishedAssetMeta(AssetMeta, Publishable):
-    pass
+class PublishedAsset(Asset, Publishable):
+
+    schemaKey = "Asset"
+
+    @validator("digest")
+    def digest_bothhashes(cls, values):
+        try:
+            if len(values[DigestType.dandi_etag] + values[DigestType.sha2_256]) != 96:
+                raise ValueError
+        except (KeyError, ValueError):
+            raise ValueError("Digest must have both valid dandi-etag and sha2-256.")
+        return values
 
 
 def get_schema_version():
